"use strict";
// tslint:disable no-redundant-jsdoc
Object.defineProperty(exports, "__esModule", { value: true });
const selenium_webdriver_1 = require("selenium-webdriver");
class SeleniumNode {
    constructor(element) {
        this.element = element;
    }
    async click() {
        return this.element.click();
    }
    async doubleClick() {
        return this.element.getDriver()
            .actions({ bridge: true })
            .doubleClick(this.element)
            .perform();
    }
    async execute(script, ...args) {
        return this.element
            .getDriver()
            .executeScript(script, this.element, ...args);
    }
}
/**
 * @implements https://pageobject.js.org/api/web/interfaces/webadapter.html
 */
class SeleniumAdapter {
    /**
     * @param capabilities https://github.com/SeleniumHQ/selenium/wiki/DesiredCapabilities
     */
    static async create(capabilities) {
        return new SeleniumAdapter(
        // tslint:disable-next-line await-promise
        await new selenium_webdriver_1.Builder().withCapabilities(capabilities).build());
    }
    /**
     * @param driver http://seleniumhq.github.io/selenium/docs/api/javascript/module/selenium-webdriver/index_exports_WebDriver.html
     */
    constructor(driver) {
        this.driver = driver;
    }
    async execute(script, ...args) {
        return this.driver.executeScript(script, ...args);
    }
    async findNodes(selector, ancestor) {
        const ancestorElement = ancestor && ancestor.element;
        return (await (ancestorElement || this.driver).findElements(selenium_webdriver_1.By.css(selector))).map(element => new SeleniumNode(element));
    }
    async goto(url) {
        return this.driver.navigate().to(url);
    }
    async press(key) {
        let seleniumKey;
        switch (key) {
            case 'Enter': {
                seleniumKey = selenium_webdriver_1.Key.ENTER;
                break;
            }
            case 'Escape': {
                seleniumKey = selenium_webdriver_1.Key.ESCAPE;
                break;
            }
            case 'Tab': {
                seleniumKey = selenium_webdriver_1.Key.TAB;
                break;
            }
            default: {
                seleniumKey = key;
            }
        }
        return this.driver
            .actions({ bridge: true })
            .sendKeys(seleniumKey)
            .perform();
    }
    async quit() {
        return this.driver.quit();
    }
}
exports.SeleniumAdapter = SeleniumAdapter;
//# sourceMappingURL=SeleniumAdapter.js.map